'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var highlight = require('@lezer/highlight');
var lr = require('@lezer/lr');
var language = require('@codemirror/language');

const hclHighlight = highlight.styleTags({
    "for in if else endfor endif": highlight.tags.controlKeyword,
    "Attribute/Identifier": highlight.tags.definition(highlight.tags.propertyName),
    "ForIntro/Identifier": highlight.tags.definition(highlight.tags.propertyName),
    "Block/Identifier": highlight.tags.definitionKeyword,
    "FunctionCall/Identifier": highlight.tags.function(highlight.tags.variableName),
    "Attribute/Expression": highlight.tags.attributeValue,
    "VariableExpr/Identifier": highlight.tags.variableName,
    "GetAttr/Identifier": highlight.tags.variableName,
    Identifier: highlight.tags.name,
    "LiteralValue/...": highlight.tags.literal,
    "StringLit/... TemplateLiteral": highlight.tags.string,
    NumericLit: highlight.tags.number,
    BoolLit: highlight.tags.bool,
    NullLit: highlight.tags.null,
    Comment: highlight.tags.comment,
    LineComment: highlight.tags.lineComment,
    BlockComment: highlight.tags.blockComment,
    "( )": highlight.tags.paren,
    "{ }": highlight.tags.bracket,
    "[ ]": highlight.tags.squareBracket,
    ArithOp: highlight.tags.arithmeticOperator,
    LogicOp: highlight.tags.logicOperator,
    CompareOp: highlight.tags.compareOperator,
    ControlOp: highlight.tags.controlOperator,
    HeredocIdentifier: highlight.tags.special(highlight.tags.controlKeyword),
    HeredocStart: highlight.tags.special(highlight.tags.brace),
    "TemplateInterpolationStart TemplateInterpolationEnd": highlight.tags.special(highlight.tags.brace),
    "TemplateDirectiveStart TemplateDirectiveEnd": highlight.tags.special(highlight.tags.brace),
    StripMarker: highlight.tags.special(highlight.tags.brace),
    Ellipsis: highlight.tags.punctuation,
    ": =>": highlight.tags.punctuation,
    ",": highlight.tags.separator,
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const QuotedTemplateStart = 1,
  QuotedTemplateEnd = 2,
  TemplateInterpolationStart = 3,
  TemplateInterpolationEnd = 4,
  TemplateDirectiveStart = 5,
  TemplateDirectiveEnd = 6,
  HeredocIdentifier = 7,
  templateLiteralChunk = 87;

const ContextType = {
  QUOTED_TEMPLATE: 1,
  TEMPLATE_INTERPOLATION: 2,
  TEMPLATE_DIRECTIVE: 4,
  HEREDOC_TEMPLATE: 8,
};

const hashStr = function (str) {
  var hash = 0,
    i,
    chr;
  if (str.length === 0) return hash;
  for (i = 0; i < str.length; i++) {
    chr = str.charCodeAt(i);
    hash = (hash << 5) - hash + chr;
    hash |= 0; // Convert to 32bit integer
  }
  return hash;
};

class Context {
  constructor(parent, type, heredoc_identifier) {
    this.parent = parent;
    this.type = type;
    this.heredoc_identifier = heredoc_identifier;
    this.hash =
      (parent ? (parent.hash + parent.hash) << 8 : 0) +
      (type << 4) +
      (this.heredoc_identifier === "" ? 0 : hashStr(this.heredoc_identifier));
  }
}

const topCtx = new Context(null, "", "");

const trackTemplate = new lr.ContextTracker({
  start: topCtx,
  shift(context, term, stack, input) {
    if (term === QuotedTemplateStart) {
      return new Context(context, ContextType.QUOTED_TEMPLATE, "");
    }
    if (term === TemplateInterpolationStart) {
      return new Context(context, ContextType.TEMPLATE_INTERPOLATION, "");
    }
    if (term === TemplateDirectiveStart) {
      return new Context(context, ContextType.TEMPLATE_DIRECTIVE, "");
    }
    if (
      term === HeredocIdentifier &&
      context.type !== ContextType.HEREDOC_TEMPLATE
    ) {
      const ctx = new Context(
        context,
        ContextType.HEREDOC_TEMPLATE,
        input.read(input.pos, stack.pos)
      );
      return ctx;
    }

    if (
      term === HeredocIdentifier &&
      context.type === ContextType.HEREDOC_TEMPLATE
    ) {
      return context.parent;
    }
    switch (term) {
      case QuotedTemplateEnd:
      case TemplateInterpolationEnd:
      case TemplateDirectiveEnd:
        return context.parent;
    }

    return context;
  },
  hash(context) {
    return context.hash;
  },
});

// export const insertSemicolon = new ExternalTokenizer(
//   (input, stack) => {
//     let { next } = input;
//     if (next == braceR || next == -1 || stack.context)
//       input.acceptToken(insertSemi);
//   },
//   { contextual: true, fallback: true }
// );

const scanQuotedTemplateStart = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(QuotedTemplateStart) &&
      !(stack.context && stack.context.type === ContextType.QUOTED_TEMPLATE) &&
      String.fromCharCode(input.next) === '"'
    ) {
      input.advance();
      return input.acceptToken(QuotedTemplateStart);
    }
  },
  { contextual: true, fallback: true }
);
const scanQuotedTemplateEnd = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(QuotedTemplateEnd) &&
      stack.context &&
      stack.context.type === ContextType.QUOTED_TEMPLATE &&
      String.fromCharCode(input.next) === '"'
    ) {
      input.advance();
      return input.acceptToken(QuotedTemplateEnd);
    }
  },
  { contextual: true, fallback: true }
);

const scanTemplateLiteralChunk = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(templateLiteralChunk) &&
      stack.context &&
      stack.context.type === ContextType.QUOTED_TEMPLATE
    ) {
      switch (String.fromCharCode(input.next)) {
        case "\\":
          input.advance();
          switch (String.fromCharCode(input.next)) {
            case '"':
            case "n":
            case "r":
            case "t":
            case "\\":
              input.advance();
              return input.acceptToken(templateLiteralChunk);
            case "u":
              for (let i = 0; i < 4; i++) {
                input.advance();
                if (!/[0-9a-fA-F]/.test(String.fromCharCode(input.next))) {
                  return;
                }
              }
              input.advance();
              return input.acceptToken(templateLiteralChunk);
            case "U":
              for (let i = 0; i < 8; i++) {
                input.advance();
                if (!/[0-9a-fA-F]/.test(String.fromCharCode(input.next))) {
                  return;
                }
              }
              input.advance();
              return input.acceptToken(templateLiteralChunk);
            default:
              return;
          }
      }
    }

    if (
      stack.canShift(templateLiteralChunk) &&
      stack.context &&
      (stack.context.type === ContextType.QUOTED_TEMPLATE ||
        stack.context.type === ContextType.HEREDOC_TEMPLATE) &&
      input.next !== -1
    ) {
      input.advance();
      return input.acceptToken(templateLiteralChunk);
    }
  },
  { contextual: true, fallback: true }
);
const scanTemplateInterpolationStart = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(TemplateInterpolationStart) &&
      stack.canShift(templateLiteralChunk) &&
      !(
        stack.context &&
        stack.context.type === ContextType.TEMPLATE_INTERPOLATION
      ) &&
      String.fromCharCode(input.next) === "$"
    ) {
      input.advance();
      if (String.fromCharCode(input.next) === "{") {
        input.advance();
        return input.acceptToken(TemplateInterpolationStart);
      }

      // escape sequence
      if (String.fromCharCode(input.next) === "$") {
        input.advance();
        if (String.fromCharCode(input.next) === "{") {
          // $${
          input.advance();
          return input.acceptToken(templateLiteralChunk);
        }
      }

      return input.acceptToken(templateLiteralChunk);
    }
  },
  { contextual: true, fallback: true }
);
const scanTemplateInterpolationEnd = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(TemplateInterpolationEnd) &&
      stack.context &&
      stack.context.type === ContextType.TEMPLATE_INTERPOLATION &&
      String.fromCharCode(input.next) === "}"
    ) {
      input.advance();
      return input.acceptToken(TemplateInterpolationEnd);
    }
  },
  { contextual: true, fallback: true }
);
const scanTemplateDirectiveStart = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(TemplateDirectiveStart) &&
      stack.canShift(templateLiteralChunk) &&
      !(
        stack.context && stack.context.type === ContextType.TEMPLATE_DIRECTIVE
      ) &&
      String.fromCharCode(input.next) === "%"
    ) {
      input.advance();
      if (String.fromCharCode(input.next) === "{") {
        input.advance();
        return input.acceptToken(TemplateDirectiveStart);
      }

      // escape sequence
      if (String.fromCharCode(input.next) === "%") {
        input.advance();
        if (String.fromCharCode(input.next) === "{") {
          // $${
          input.advance();
          return input.acceptToken(templateLiteralChunk);
        }
      }

      return input.acceptToken(templateLiteralChunk);
    }
  },
  { contextual: true, fallback: true }
);
const scanTemplateDirectiveEnd = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(TemplateDirectiveEnd) &&
      stack.context &&
      stack.context.type === ContextType.TEMPLATE_DIRECTIVE &&
      String.fromCharCode(input.next) === "}"
    ) {
      input.advance();
      return input.acceptToken(TemplateDirectiveEnd);
    }
  },
  { contextual: true, fallback: true }
);

const scanHeredocIdentifier = new lr.ExternalTokenizer(
  (input, stack) => {
    if (
      stack.canShift(HeredocIdentifier) &&
      !(stack.context && stack.context.type === ContextType.HEREDOC_TEMPLATE) &&
      input.next !== -1
    ) {
      let next = String.fromCharCode(input.next);
      while (/[0-9a-zA-Z]/.test(next) || next === "_" || next === "-") {
        input.advance();
        next = String.fromCharCode(input.next);
      }

      return input.acceptToken(HeredocIdentifier);
    }

    if (
      stack.canShift(HeredocIdentifier) &&
      stack.canShift(templateLiteralChunk) &&
      stack.context &&
      stack.context.type === ContextType.HEREDOC_TEMPLATE &&
      input.next != -1
    ) {
      const expected = stack.context.heredoc_identifier;

      let has_leading_whitespace_with_newline = false;
      let has_leading_whitespace = false;
      let next = String.fromCharCode(input.next);
      while (/\s/.test(next)) {
        has_leading_whitespace = true;
        if (next === "\n") {
          has_leading_whitespace_with_newline = true;
        }
        input.advance();
        next = String.fromCharCode(input.next);
      }
      if (has_leading_whitespace) {
        input.acceptToken(templateLiteralChunk);
      }

      if (!has_leading_whitespace_with_newline) {
        return;
      }

      let advance = 0;
      for (let i = 0; i < expected.length; i++) {
        if (String.fromCharCode(input.next) === expected[i]) {
          input.advance();
          advance++;
        } else {
          if (advance) {
            input.acceptToken(templateLiteralChunk);
          }
          return
        }
      }

      // check if the identifier is on a line of its own
      let i = 0;
      while (true) {
        const ch = input.peek(i);
        if (ch == -1 || String.fromCharCode(ch) === "\n") {
          return input.acceptToken(HeredocIdentifier);
        }

        if (!/\s/.test(String.fromCharCode(ch))) {
          return input.acceptToken(templateLiteralChunk);
        }

        i++;
      }
    }
  },
  { contextual: true, fallback: true }
);

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_Identifier = {__proto__:null,true:39, false:41, null:45, for:64, in:66, endfor:70, if:76, else:80, endif:84};
const parser = lr.LRParser.deserialize({
  version: 14,
  states: "EzQ]Q&jOOPeO&jOOOmQ&kO'#D]O!kQ&kO'#CiOOQO'#EO'#EOO!yQ&jO'#ChQOQ&jOOPOOO'#Cd'#CdPOOO)C?|)C?|OOQy'#Cn'#CnOOQy'#Cq'#CqO#UQ)vO'#CvOOQy'#Cl'#ClOOQ!b'#DY'#DYO#dQ'|O'#DXOOQy'#Cu'#CuO$gQ&kO'#D[O$nQ&jO'#D^O%tQ&kO'#EeO&OQ&kO'#D]OOQy,59w,59wO&VQ&jO,59wOOQy'#DZ'#DZO'lQ'dO'#D_OOQy'#Dc'#DcOOQP'#Dj'#DjOOQP'#Dk'#DkO$yQ&kO'#DiO)|Q'dO'#CkOOQy'#Dh'#DhOOQy'#EZ'#EZO$yQ&kO'#EZOOQy'#Ck'#CkO#_Q)`O'#CsO$yQ&kO,59TOOQP'#ET'#ETO*sQ&kO,5:iO+OQ&jO,5:iOOQO-E7|-E7|O+WQ+YO'#CtO+iQ)vO,59_O+wQ&sO'#CwO,RQ)tO'#CzO,^Q)tO'#DQOOQ%n'#Cy'#CyOOQ%n'#EP'#EPO,iQ)vO,59bOOQy,59b,59bO,wQ&jO'#DRO-SQ+WO,59sO-bQ&jO'#EbOOQy,59v,59vO-mQ&jO,59vO$yQ&kO,5:OO-rQ&jO'#DeO-wQ&kO,59xOOQP'#D{'#D{O$yQ&kO,5:fOOQP'#ER'#ERO.rQ&kO,5;PO.yQ&kO,5;PO/TQ&kO,5:ROOQy1G/c1G/cO0OQ&kO,59zOOQy,5:T,5:TOOQP'#Dm'#DmOOQP'#Dn'#DnOOQP'#Do'#DoOOQP'#Dp'#DpOOQP'#Dq'#DqOOQP'#Dr'#DrO$yQ&kO,5:WO$yQ&kO,5:WO$yQ&kO,5:WO$yQ&kO,5:WO$yQ&kO,5:WO$yQ&kO,5:WO$yQ&kO'#DtOOQy'#Ds'#DsO0VQ&jO'#DvOOQy'#Dx'#DxOOQy'#Dy'#DyOOQy'#Dw'#DwOOQy,5:u,5:uO0[Q&jO,5:uO0dQ&lO,59_O0iQ&jO1G.oOOQP-E8R-E8RO0wQ&jO1G0TOOQO1G0T1G0TO0zQ&jO1G0TO+WQ+YO'#E[OOQ%n,59`,59`OOQy1G.y1G.yOOQ%n,59c,59cO1PQ&sO,59cO1ZQ&rO,59cOOQ%n,59f,59fO,RQ)tO,59fO1fQ&jO'#DOOOQ%n,59l,59lO1tQ)tO,59lO,^Q)tO,59lO2PQ&jO'#DTOOQ%n-E7}-E7}OOQy1G.|1G.|O2bQ&jO,59gO2gQ&jO,59mO$yQ&kO,59mO2oQ+WO1G/_OOQy1G/_1G/_O2}Q&kO,5:|O3UQ&jO,5:|OOQy1G/b1G/bO3^Q&jO1G/jO3iQ&jO,5:PO3qQ&kO1G/dOOQP'#D_'#D_O4uQ&jO1G0QOOQP,5:m,5:mO4}Q&kO1G0kOOQP-E8P-E8PO5UQ,UO'#D_O5]Q,UO1G/mO6oQ,UO'#CkO6yQ&jO'#DaOOQy1G/f1G/fO7XQ&jO1G/fOOQy1G/r1G/rO9^Q'dO1G/rO9hQ'dO1G/rO;rQ'dO1G/rO;|Q'dO1G/rO=nQ'dO1G/rO>bQ&jO,5:`OOQy,5:b,5:bPOQy'#ES'#ESPOQy,5:d,5:dPOQy,5:e,5:eOOQy1G0a1G0aOOQO7+%o7+%oO>jQ&jO7+%oOOQ%n,5:v,5:vOOQ%n1G.}1G.}O>oQ&rO1G.}O>tQ&rO1G.}OOQ%n1G/Q1G/QO?PQ&jO,59jO?[Q'[O,59jOOQ%n1G/W1G/WO1tQ)tO1G/WO?dQ&jO'#DVO1tQ)tO1G/WO?rQ&jO,59oO@QQ'[O,59oO@YQ'[O,59qO@bQ&jO1G/RO@jQ&jO1G/RO$yQ&kO1G/XO@oQ'[O1G/XOOQy7+$y7+$yO@zQ&jO,5:lOA]Q&kO1G0hOOQO-E8O-E8OOOQy7+%U7+%UOAdQ&jO7+%UO$yQ&kO'#DfO$yQ&kO1G/kOAiQ&jO1G/kOOQP'#D|'#D|O$yQ&kO7+%lP$yQ&kO'#ERO$yQ&kO7+%XOAnQ&kO,59{OAuQ&jO,59{OOQO,59{,59{OOQy7+%Q7+%QOOQy1G/z1G/zPOQy-E8Q-E8QOOQO<<IZ<<IZOOQ%n7+$i7+$iOBQQ&rO7+$iOBVQ'[O1G/UOOQ%n1G/U1G/UOB_Q'[O1G/UOOQ%n7+$r7+$rOBdQ&jO,59qO1tQ)tO7+$rOBoQ'[O1G/ZOBwQ'[O1G/]OOQ$Y1G/Z1G/ZOCPQ'[O1G/ZOOQ%n1G/]1G/]OCUQ'[O1G/]O$yQ&kO7+$mOCZQ&jO7+$mOC`Q&jO7+$mOChQ'[O7+$sOOQ$Y7+$s7+$sOCsQ'[O7+$sP$yQ&kO'#EQOOQy<<Hp<<HpOCxQ&jO,5:QODTQ&jO7+%VOD]Q&jO7+%VOOQy<<IW<<IWODbQ&jO<<HsOE}Q,UO1G/rOGcQ,UO1G/rOHwQ,UO1G/rOJ]Q,UO1G/rOJdQ,UO1G/rOJkQ&kO1G/gOOQO1G/g1G/gOOQ%n<<HT<<HTOOQ%n7+$p7+$pOJrQ'[O7+$pOOQ%n<<H^<<H^OOQ$Y7+$u7+$uOJwQ'[O7+$uOOQ%n7+$w7+$wOJ|Q'[O7+$wOKRQ'[O<<HXOK^Q&jO<<HXO$yQ&kO<<HXOKcQ&jO<<HXOOQ$Y<<H_<<H_OKhQ'[O<<H_OOQP<<Hq<<HqO$yQ&kO<<HqOOQyAN>_AN>_OKmQ&jOAN>_OKrQ&jOAN>_OOQ%n<<H[<<H[OOQ$Y<<Ha<<HaOOQ%n<<Hc<<HcOOQ$YAN=sAN=sOKzQ'[OAN=sO$yQ&kOAN=sOLPQ'[OAN=sOL[Q&jOAN=sOOQ$YAN=yAN=yOLaQ&jOAN>]OOQyG23yG23yOLiQ&jOG23yOOQ$YG23_G23_OLnQ'[OG23_OLyQ'[OG23_O$yQ&kOG23_OOQPG23wG23wOOQyLD)eLD)eOOQ$YLD(yLD(yOMOQ'[OLD(yOMTQ'[OLD(yOOQ$Y!$'Le!$'LeOM`Q'[O!$'LeOOQ$Y!)9BP!)9BPO-wQ&kO'#DiO/TQ&kO'#DiOMeQ&kO'#CkO-wQ&kO,5:WO/TQ&kO,5:WO-wQ&kO,5:WO/TQ&kO,5:WO-wQ&kO,5:WO/TQ&kO,5:WO-wQ&kO,5:WO/TQ&kO,5:WO-wQ&kO,5:WO/TQ&kO,5:WO-wQ&kO,5:WO/TQ&kO,5:WON[Q&kO1G/rO! XQ&kO1G/rO!!UQ&kO1G/rO!%UQ&kO1G/rO!%]Q&kO1G/rO-wQ&kO7+%lO/TQ&kO7+%lO4uQ&jO1G0QO4uQ&jO1G0QO$yQ&kO,5:fO$yQ&kO,5:f",
  stateData: "!%l~O!{OSXPQYPQ~O^RO#WQO~OXVOYVO~OPZO^gOa[OcXOdXOfYO#Q]O#R]O#T`O#VdO#WcO#[oO#^iO#_jO~OPqO^sO!|rO#WuO~O^RO!x[X#V[X~OQ!PORyOT!QO!ywO~OV!RO~OPZO^gOa[OcXOdXOfYOp!WO#Q]O#R]O#T`O#WcO#[oO#^iO#_jO~O#S!TO~P#iO!|!XO#Y!XO#o!YO~OPZO^gOa[OcXOdXOfYO#Q]O#R]O#T`O#WcO#[oO#^iO#_jO~O#P!]O#V#XX~P$yOp!WO~PmO#V!`O~O#[!aO!i!RX#T!RX#^!RX#`!RX#a!RX#b!RX#c!RX#d!RX#e!RX#f!RX#g!RX#h!RX#i!RX#j!RX#k!RX#l!RX#m!RX#n!RX#o!RX~O!|!RX#Y!RX#P!RX#S!RX#Z!RX^!RX!x!RXS!RXl!RXv!RX!U!RXU!RX#V!RX~P&[O!i!pO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO#h!fO#i!fO#j!gO#k!hO#l!qO#m!rO#n!sO#o_X#P_X^_X#V_X~O#T!oO!|_X#Y_X#S_X#Z_X!x_XS_Xl_Xv_X!U_XU_X~P(iOPqO^sO#W!zO~O^RO#V!{O~O!y!}OQ#OPR#OPT#OPV#OP~OQ#POR!sXT!sX!y!sX~OS#QOl#RO~P$yORyOT#VO!ywO~ORyOT#ZO!ywO~OQ#]ORyOT!QO!ywO~Ol#_Op#^Ov#`O~ORyOT!QOV#bO!ywO~O#P#cO#o!YO#S#UX~O#S#eO~O^#gO~OPZO^#iOa[OcXOdXOfYO#Q]O#R]O#T`O#WcO#[oO#^iO#_jO~O#V#Xa~P$yO#P#lO#V#Xa~P$yOPZO^#nOa[OcXOdXOfYO#Q]O#R]O#T`O#WcO#[oO#^iO#_jO~O#Z#rO~P$yO^#{O~O#Z$PO#o!YO~OQ#PO~O#o!YO^]i!x]i#V]i~O^RO#V$QO~OS$TOl$UO~P$yOS$TOl$UO#o!YO~Ol$XOp#^Os$YOv#`O~ORyOT$]O!ywO~Ol$_Op#^Ov#`Ox$`Oz$aO~O^$bO~Op$cOv$dO~ORyOT!QOV$fO!ywO~O#S#Ua~P$yO#P$hO#S#Ua~Ov$lO#S$jO#o!YO~Oq$mO#P$nO~O#o!YOP!Qi^!Qia!Qic!Qid!Qif!Qi#P!Qi#Q!Qi#R!Qi#T!Qi#V!Qi#W!Qi#[!Qi#^!Qi#_!Qi~O#Y$oO#o!YO~O#V#Xi~P$yO#]!RX~P&[O#]$rO#o!YO~O!i!pO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO#h!fO#i!fO#j!gO#k!hO#l!qO#m!rO#n!sO#o_X~O#T!oO#]_X~P5eO!U$uO#P$sO#o!YO#Z!TX~O#Z$vO~O#`!cO#a!cO#b!cO!i!`i!|!`i#T!`i#Y!`i#d!`i#e!`i#f!`i#g!`i#h!`i#i!`i#j!`i#k!`i#l!`i#m!`i#n!`i#o!`i#P!`i#S!`i#Z!`i^!`i!x!`iS!`il!`iv!`i!U!`iU!`i#V!`i~O#^!`i#c!`i~P7^O#^!dO#c!dO~P7^O#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO!i!`i!|!`i#T!`i#Y!`i#j!`i#k!`i#l!`i#m!`i#n!`i#o!`i#P!`i#S!`i#Z!`i^!`i!x!`iS!`il!`iv!`i!U!`iU!`i#V!`i~O#h!`i#i!`i~P9rO#h!fO#i!fO~P9rO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO#h!fO#i!fO#j!gO!i!`i#T!`i#k!`i#l!`i#m!`i#n!`i#o!`i#P!`i^!`i#V!`i~O!|!`i#Y!`i#S!`i#Z!`i!x!`iS!`il!`iv!`i!U!`iU!`i~P<WO#S$wO#o!YO~O#V$yO~OS$zO~OS$zOl${O#o!YO~Op$cOs$|Ov$dO~OU$}Ol%OO~Ol%QOp#^Ov#`Oz$aO~Op$cOv$dOx%SOz%TO~OU%UOl%VO~OU%WOl%XO~Oq%YO#P%ZO~O^%[O~OU%^Ol%_O#o!YO~O#o!YO#P!ta#S!ta!U!ta#Z!ta~O#S#Ui~P$yO#S%aO~O^%dO~O#Z!Ta~P$yO!U%mO#P%lO#Z!Ta~OS%nO~OU%oOl%pO~OU%oO~Op$cOv$dOz%TO~OU%rOl%sO~OU%tOl%uO~OU%rO~OU%tO~O^%wO~Oq%xO#P%yO~OU%zOl%{O#o!YO~OU%zO~O#o!YO#S!Ya#V!Ya~O#Y%|O#o!YO~Oq%}O~Ov$lO!U&QO#V&OO#o!YO~O#`!cO#a!cO#b!cO!i!`i#T!`i#^!`i#c!`i#d!`i#e!`i#f!`i#g!`i#h!`i#i!`i#j!`i#k!`i#l!`i#m!`i#n!`i#o!`i~O#]!`i~PDpO#^!dO#`!cO#a!cO#b!cO#c!dO!i!`i#T!`i#d!`i#e!`i#f!`i#g!`i#h!`i#i!`i#j!`i#k!`i#l!`i#m!`i#n!`i#o!`i~O#]!`i~PFUO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO!i!`i#T!`i#h!`i#i!`i#j!`i#k!`i#l!`i#m!`i#n!`i#o!`i~O#]!`i~PGjO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO#h!fO#i!fO!i!`i#T!`i#]!`i#k!`i#l!`i#m!`i#n!`i#o!`i~O#j!`i~PIOO#j!gO~PIOO#Z!Ti~P$yOU&RO~OU&SO~OU&TO~OU&UOl&VO#o!YO~Oq&WO~O^&YO~OU&ZO~O#V&]O~Ov$lO#V&]O~OU&_O~OU&_Ol&aO#o!YO~Oq&bO~O#Y&cO#o!YO~O#V&dO~OU&eOl&fO#o!YO~OU&eO~OU&hO~OU&hOl&iO#o!YO~OU&jO~OP_Xa_Xc_Xd_Xf_X#Q_X#R_X#T_X#W_X#[_X#__X~P(iOP!`i^!`ia!`ic!`id!`if!`i#P!`i#Q!`i#R!`i#V!`i#W!`i#[!`i#_!`i~PDpOP!`i^!`ia!`ic!`id!`if!`i#P!`i#Q!`i#R!`i#V!`i#W!`i#[!`i#_!`i~PFUOP!`i^!`ia!`ic!`id!`if!`i#P!`i#Q!`i#R!`i#V!`i#W!`i#[!`i#_!`i~PGjO#^!dO#`!cO#a!cO#b!cO#c!dO#d!eO#e!eO#f!eO#g!eO#h!fO#i!fOP!`i^!`ia!`ic!`id!`if!`i!i!`i#P!`i#Q!`i#R!`i#T!`i#V!`i#W!`i#[!`i#_!`i#k!`i#l!`i#m!`i#n!`i#o!`i~O#j!`i~P!#RO#j!gO~P!#ROa!i#l^X#a^~",
  goto: "=u#YPPPPPPPP#ZPPP#^#gP#m%kP&zPP&zP(Z)n%k*R+bP+b+p,OPP,^P+p,dP,rP,xP*R-W%k.g/v1Y%k%k1gP%k1j2y3P1j%k3Y4i4i3Y5|6f6{7_7n7z8T8YP8T8T8^8^8c9]9|#g:V:_:y;TP;ZPPPPP;a=hPPPPP=nPP=qRWPQUOQ!|uR$R!zXSOTu!z^aQbc!]!^#l$qQ!S`Q!voQ!xrQ#SyQ#f!VQ#h!XQ#j!ZQ#o!_Q#q!aQ#z!oQ$V#RQ$e#`Y$g#c$h$s%`%lQ%]$dQ%b$lQ%c$mU%e$p'P'QQ%f$rQ%v%YQ&X%xQ&[%}Q&`&WQ&g&bQ'R'TR'S'U#knQ`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'U#k[Q`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'U#j[Q`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'UTsRtQxZf}z{!O!R#U#X#Y#a$[$^%RR!wq#k_Q`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'Ui}Zz{!O!R#U#X#Y#a$[$^%Ri|Zz{!O!R#U#X#Y#a$[$^%RizZz{!O!R#U#X#Y#a$[$^%RQ#TzR$W#Ui{Zz{!O!R#U#X#Y#a$[$^%RQ#X{R$^#YQ#W{S$Z#X#YS%P$[$^R%q%R#k^Q`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'U#kfQ`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'UQUO#kfQ`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'USbQcS![b!^V#k!]#l$qR#s!a#khQ`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'UQ!V`R!_cQ$k#fQ&P%fR&^&Q#kmQ`bckory!V!X!Z!]!^!_!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b&k&l&n&o&p&q&r&s&t&u&v&w&x&y'P'Q'T'U!tkQ`bckory!V!Z!]!^!a!i!j!k!l!m!n!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b'T'Ub&k!X&k&n&p&r&t&v&x'Pc&l!_&l&o&q&s&u&w&y'Q[!il#u#v#w#x#y[&n&m&z&{&|&}'O]&o#p%g%h%i%j%kY!jl#v#w#x#yY&p&m&{&|&}'OZ&q#p%h%i%j%kW!kl#w#x#yW&r&m&|&}'OX&s#p%i%j%kU!ll#x#yU&t&m&}'OV&u#p%j%kS!ml#yS&v&m'OT&w#p%kQ!nlQ&x&mR&y#pV!ul#p&mT!pl#pV!tl#p&m!opQ`bcory!V!X!Z!]!^!_!a!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b'P'Q'T'U!O!Za!S!v!x#S#f#j#q#z$V$e$g%]%b%c%f%v&X&[&`&g'R'SQ'T#hR'U#oQ$p#jQ'P'RR'Q'SUTOu!zRvTQ!OZQ#UzQ#Y{[#[!O#U#Y#a$[%RQ#a!RQ$[#XR%R$^Q#d!SS$i#d$tR$t#qQ!^bR#m!^QtRR!yt!flQ`bcory!V!Z!]!^!a!o#R#`#c#l$d$h$l$m$p$q$r$s%Y%`%l%x%}&W&b'T'UU!bk&k&lS#p!_'QU#t!i&n&oQ#u!jQ#v!kQ#w!lQ#x!mQ#y!nQ%g&qQ%h&sQ%i&uQ%j&wQ%k&yS&m!X'PQ&z&pQ&{&rQ&|&tQ&}&vR'O&xQ#OwR$S!}R!U`TeQc",
  nodeNames: "⚠ QuotedTemplateStart QuotedTemplateEnd TemplateInterpolationStart TemplateInterpolationEnd TemplateDirectiveStart TemplateDirectiveEnd HeredocIdentifier Comment LineComment BlockComment ConfigFile Body Attribute Identifier Expression LiteralValue NumericLit BoolLit true false NullLit null StringLit TemplateLiteral TemplateExpr QuotedTemplate TemplateInterpolation StripMarker TemplateDirective TemplateFor TemplateForStart for in TemplateForEnd endfor TemplateIf TemplateIfIntro if TemplateElseIntro else TemplateIfEnd endif HeredocTemplate HeredocStart CollectionValue Tuple Object ObjectElem VariableExpr FunctionCall FunctionArguments Ellipsis ForExpr ForTupleExpr ForIntro ForCond ForObjectExpr Operation UnaryOperation ArithOp LogicOp BinaryOperation ArithOp ArithOp CompareOp CompareOp LogicOp LogicOp Index NewIndex LegacyIndex GetAttr Splat AttrSplat FullSplat Conditional ControlOp ControlOp Block",
  maxTerm: 123,
  context: trackTemplate,
  skippedNodes: [0,8,9,10],
  repeatNodeCount: 6,
  tokenData: "-h~RvX^#ipq#iqr$^st$kuv%Svw%Xxy%dyz%iz{%n{|%s|}%x}!O%}!O!P&S!P!Q&z!Q!R(^!R![)l![!]*c!^!_*h!_!`+V!`!a+l!a!b+y!c!},O!}#O,d#P#Q,w#R#S,O#T#o,O#o#p,|#p#q-R#q#r-^#r#s-c#y#z#i$f$g#i#BY#BZ#i$IS$I_#i$I|$JO#i$JT$JU#i$KV$KW#i&FU&FV#i~#nY!{~X^#ipq#i#y#z#i$f$g#i#BY#BZ#i$IS$I_#i$I|$JO#i$JT$JU#i$KV$KW#i&FU&FV#i~$cP#_~!_!`$f~$kO#i~~$pSX~OY$kZ;'S$k;'S;=`$|<%lO$k~%PP;=`<%l$k~%XO#b~~%[Pvw%_~%dO#j~~%iO#[~~%nO#Z~~%sO#`~~%xO#c~~%}O#P~~&SO#^~~&XR#l~z{&b!O!P&g!Q![&r~&gO#m~~&jP!O!P&m~&rO!U~~&wP!i~!Q![&r~'PQ#a~z{'V!P!Q$k~'YTOz'Vz{'i{;'S'V;'S;=`(W<%lO'V~'lVOz'Vz{'i{!P'V!P!Q(R!Q;'S'V;'S;=`(W<%lO'V~(WOY~~(ZP;=`<%l'V~(cRa~!O!P(l!Q![)l#l#m)w~(oP!Q![(r~(wRa~!Q![(r!g!h)Q#X#Y)Q~)TR{|)^}!O)^!Q![)d~)aP!Q![)d~)iPa~!Q![)d~)qQa~!O!P(l!Q![)l~)zR!Q![*T!c!i*T#T#Z*T~*YRa~!Q![*T!c!i*T#T#Z*T~*hO#Y~~*mQ#f~!^!_*s!_!`+Q~*xP#Q~}!O*{~+QO#R~~+VO#g~~+[Q!|P!_!`+b!`!a+g~+gO#h~Q+lO#]Q~+qP#d~!_!`+t~+yO#e~~,OO#o~~,TT^~}!O,O!Q![,O!c!},O#R#S,O#T#o,O~,iP#T~z{,l~,oP#P#Q,r~,wO#n~~,|O#S~~-RO#W~~-UP#p#q-X~-^O#k~~-cO#V~~-hOl~",
  tokenizers: [scanQuotedTemplateStart, scanQuotedTemplateEnd, scanTemplateInterpolationStart, scanTemplateInterpolationEnd, scanTemplateDirectiveStart, scanTemplateDirectiveEnd, scanHeredocIdentifier, scanTemplateLiteralChunk, 0, 1],
  topRules: {"ConfigFile":[0,11]},
  dynamicPrecedences: {"18":1,"21":1},
  specialized: [{term: 14, get: (value) => spec_Identifier[value] || -1}],
  tokenPrec: 2320
});

const hclLanguage = language.LRLanguage.define({
    parser: parser.configure({
        props: [
            language.indentNodeProp.add({
                Application: language.delimitedIndent({ closing: ")", align: false }),
            }),
            language.foldNodeProp.add({
                Application: language.foldInside,
            }),
            hclHighlight,
        ],
    }),
    languageData: {
        commentTokens: { line: ";" },
    },
});
function hcl() {
    return new language.LanguageSupport(hclLanguage);
}

exports.hcl = hcl;
exports.hclLanguage = hclLanguage;
